@@ -14,7 +14,7 @@ my $pt = WWW::PunchTab->new(
     secret_key => 'ed73f70966dd10b7788b8f7953ec1d07',
 );
 
-$pt->sso_auth(
+print $pt->sso_auth_js(
     {
         'id'         => '2',
         'first_name' => 'Fayland',
@@ -33,10 +33,10 @@ $pt->sso_auth(
 # my $activity = $pt->activity() or die $pt->errstr;
 # print Dumper(\$activity);
 
-my $leaderboard = $pt->leaderboard() or die $pt->errstr;
-print Dumper( \$leaderboard );
-
-#my $reward = $pt->reward() or die $pt->errstr;
+#my $leaderboard = $pt->leaderboard() or die $pt->errstr;
 #print Dumper(\$leaderboard);
 
+#my $reward = $pt->reward() or die $pt->errstr;
+#print Dumper(\$reward);
+
 1;
